# -*- rpm-spec -*-

%define _default_patch_fuzz 0

# If neither fedora nor rhel was defined, try to guess them from %{dist}
%if !0%{?rhel} && !0%{?fedora}
%{expand:%(echo "%{?dist}" | \
  sed -ne 's/^\.el\([0-9]\+\).*/%%define rhel \1/p')}
%{expand:%(echo "%{?dist}" | \
  sed -ne 's/^\.fc\?\([0-9]\+\).*/%%define fedora \1/p')}
%endif

# A client only build will create a libvirt.so only containing
# the generic RPC driver, and test driver and no libvirtd
# Default to a full server + client build
%define client_only        0

# Now turn off server build in certain cases

# RHEL-5 builds are client-only for s390, ppc
%if 0%{?rhel} == 5
%ifnarch i386 i586 i686 x86_64 ia64
%define client_only        1
%endif
%endif

# Disable all server side drivers if client only build requested
%if %{client_only}
%define server_drivers     0
%else
%define server_drivers     1
%endif


# Now set the defaults for all the important features, independent
# of any particular OS

# First the daemon itself
%define with_libvirtd      0%{!?_without_libvirtd:%{server_drivers}}
%define with_avahi         0%{!?_without_avahi:%{server_drivers}}

# Then the hypervisor drivers that run on local host
%define with_xen           0%{!?_without_xen:%{server_drivers}}
%define with_xen_proxy     0%{!?_without_xen_proxy:%{server_drivers}}
%define with_qemu          0%{!?_without_qemu:%{server_drivers}}
%define with_openvz        0%{!?_without_openvz:%{server_drivers}}
%define with_lxc           0%{!?_without_lxc:%{server_drivers}}
%define with_vbox          0%{!?_without_vbox:%{server_drivers}}
%define with_uml           0%{!?_without_uml:%{server_drivers}}
%define with_xenapi        0%{!?_without_xenapi:%{server_drivers}}
# XXX this shouldn't be here, but it mistakenly links into libvirtd
%define with_one           0%{!?_without_one:%{server_drivers}}

# Then the hypervisor drivers that talk a native remote protocol
%define with_phyp          0%{!?_without_phyp:1}
%define with_esx           0%{!?_without_esx:1}

# Then the secondary host drivers
%define with_network       0%{!?_without_network:%{server_drivers}}
%define with_storage_fs    0%{!?_without_storage_fs:%{server_drivers}}
%define with_storage_lvm   0%{!?_without_storage_lvm:%{server_drivers}}
%define with_storage_iscsi 0%{!?_without_storage_iscsi:%{server_drivers}}
%define with_storage_disk  0%{!?_without_storage_disk:%{server_drivers}}
%define with_storage_mpath 0%{!?_without_storage_mpath:%{server_drivers}}
%define with_numactl       0%{!?_without_numactl:%{server_drivers}}
%define with_selinux       0%{!?_without_selinux:%{server_drivers}}

# A few optional bits off by default, we enable later
%define with_polkit        0%{!?_without_polkit:0}
%define with_capng         0%{!?_without_capng:0}
%define with_netcf         0%{!?_without_netcf:0}
%define with_udev          0%{!?_without_udev:0}
%define with_hal           0%{!?_without_hal:0}
%define with_yajl          0%{!?_without_yajl:0}
%define with_nwfilter      0%{!?_without_nwfilter:0}
%define with_libpcap       0%{!?_without_libpcap:0}
%define with_macvtap       0%{!?_without_macvtap:0}
%define with_libnl         0%{!?_without_libnl:0}
%define with_audit         0%{!?_without_audit:0}

# Non-server/HV driver defaults which are always enabled
%define with_python        0%{!?_without_python:1}
%define with_sasl          0%{!?_without_sasl:1}


# Finally set the OS / architecture specific special cases

# Xen is available only on i386 x86_64 ia64
%ifnarch i386 i586 i686 x86_64 ia64
%define with_xen 0
%endif

# Numactl is not available on s390[x]
%ifarch s390 s390x
%define with_numactl 0
%endif

# RHEL doesn't ship OpenVZ, VBox, UML, OpenNebula, PowerHypervisor,
# or libxenserver (xenapi)
%if 0%{?rhel}
%define with_openvz 0
%define with_vbox 0
%define with_uml 0
%define with_one 0
%define with_phyp 0
%define with_xenapi 0
%endif

# RHEL-5 has restricted QEMU to x86_64 only and is too old for LXC
%if 0%{?rhel} == 5
%ifnarch x86_64
%define with_qemu 0
%endif
%define with_lxc 0
%endif

# RHEL-6 has restricted QEMU to x86_64 only, stopped including Xen
# on all archs. Other archs all have LXC available though
%if 0%{?rhel} >= 6
%ifnarch x86_64
%define with_qemu 0
%endif
%define with_xen 0
%endif

# If Xen isn't turned on, we shouldn't build the xen proxy either
%if ! %{with_xen}
%define with_xen_proxy 0
%endif

# Fedora doesn't have any QEMU on ppc64 - only ppc
%if 0%{?fedora}
%ifarch ppc64
%define with_qemu 0
%endif
%endif

# PolicyKit was introduced in Fedora 8 / RHEL-6 or newer, allowing
# the setuid Xen proxy to be killed off
%if 0%{?fedora} >= 8 || 0%{?rhel} >= 6
%define with_polkit    0%{!?_without_polkit:1}
%define with_xen_proxy 0
%endif

# libcapng is used to manage capabilities in Fedora 12 / RHEL-6 or newer
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%define with_capng     0%{!?_without_capng:1}
%endif

# netcf is used to manage network interfaces in Fedora 12 / RHEL-6 or newer
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%define with_netcf     0%{!?_without_netcf:%{server_drivers}}
%endif

# udev is used to manage host devices in Fedora 12 / RHEL-6 or newer
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%define with_udev     0%{!?_without_udev:%{server_drivers}}
%else
%define with_hal       0%{!?_without_hal:%{server_drivers}}
%endif

# Enable yajl library for JSON mode with QEMU
%if 0%{?fedora} >= 13 || 0%{?rhel} >= 6
%define with_yajl     0%{!?_without_yajl:%{server_drivers}}
%endif

# Enable libpcap library
%if %{with_qemu}
%define with_nwfilter 0%{!?_without_nwfilter:%{server_drivers}}
%define with_libpcap  0%{!?_without_libpcap:%{server_drivers}}
%define with_macvtap  0%{!?_without_macvtap:%{server_drivers}}
%endif

%if %{with_macvtap}
%define with_libnl 1
%endif

%if 0%{?fedora} >= 11 || 0%{?rhel} >= 5
%define with_audit    0%{!?_without_audit:1}
%endif

# Force QEMU to run as non-root
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%define qemu_user  qemu
%define qemu_group  qemu
%else
%define qemu_user  root
%define qemu_group  root
%endif


# The RHEL-5 Xen package has some feature backports. This
# flag is set to enable use of those special bits on RHEL-5
%if 0%{?rhel} == 5
%define with_rhel5  1
%else
%define with_rhel5  0
%endif

ExclusiveArch: i386 x86_64 ia64

Summary: Library providing a simple API virtualization
Name: libvirt
Version: 0.8.2
Release: 15%{?dist}.4%{?extra_release}
License: LGPLv2+
Group: Development/Libraries
Source: libvirt-%{version}.tar.gz

# Patches fixing libvirt-0.8.2 build on RHEL-5
Patch1: libvirt-xen-tests-Fix-missing-type-ioemu-with-rhel5-api.patch
Patch2: libvirt-xml2sexprtest-Remove-graphics-from-unrelated-tests.patch
Patch3: libvirt-xen-tests-Fix-PV-VFB-tests-with-RHEL-5-API.patch

# RHEL-only
Patch10: libvirt-qemu-Disable-lzop-compression.patch
Patch11: libvirt-rhel-daemon.patch
Patch12: libvirt-Disable-libvirt-guests-on-xen-host.patch

# RHEL-5 patches which were applied upstream after 0.8.2
Patch100: libvirt-remote-Fix-incorrect-use-of-private-data-field.patch
Patch101: libvirt-xen-Fix-device-count-on-detach.patch
Patch102: libvirt-nodedev-Fix-sysfs-paths-for-vport-operations.patch
Patch103: libvirt-nodedev-Free-the-right-pointers-when-getting-WWNs-fails.patch
Patch104: libvirt-xen-Fix-scheduler-setting-problems.patch
Patch105: libvirt-Set-a-stable-high-MAC-addr-for-guest-TAP-devices-on-host.patch
Patch106: libvirt-Extract-the-backing-store-format-as-well-as-name-if-available.patch
Patch107: libvirt-Remove-type-field-from-FileTypeInfo-struct.patch
Patch108: libvirt-Refactor-virStorageFileGetMetadataFromFD-to-separate-functionality.patch
Patch109: libvirt-Require-format-to-be-passed-into-virStorageFileGetMetadata.patch
Patch110: libvirt-Add-an-API-for-iterating-over-disk-paths.patch
Patch111: libvirt-Convert-all-disk-backing-store-loops-to-shared-helper-API.patch
Patch112: libvirt-Pass-security-driver-object-into-all-security-driver-callbacks.patch
Patch113: libvirt-Disable-all-disk-probing-in-QEMU-driver-add-config-option-to-re-enable.patch
Patch114: libvirt-Add-ability-to-set-a-default-driver-name-type-when-parsing-disks.patch
Patch115: libvirt-Rewrite-qemu-img-backing-store-format-handling.patch
Patch116: libvirt-Use-the-extract-backing-store-format-in-storage-volume-lookup.patch
Patch117: libvirt-CVE-2010-2242-Apply-a-source-port-mapping-to-virtual-network-masquerading.patch
Patch118: libvirt-Eliminate-memory-leak-in-xenUnifiedDomainInfoListFree.patch

# Add man page for libvirtd (rhbz #618750)
Patch119: libvirt-libvirtd-add-man-page-for-libvirtd.patch
Patch120: libvirt-Fix-build-by-removing-unknown-pod2man-flag.patch
Patch121: libvirt-man-pages-update-authors-and-copyright-notice-for-libvirtd-and-virsh.patch
Patch122: libvirt-build-sys-fix-build-when-daemon-is-disabled-by-not-installing-libvirtd.8.patch

Patch123: libvirt-Remove-bogus-free-of-static-strings.patch
Patch124: libvirt-nwfilter-serialize-execution-of-scripts-with-ebtables-cmds.patch
Patch125: libvirt-nwfilter-Discard-class-D-E-IP-addresses-when-sniffing-pkts.patch
Patch126: libvirt-nwfilter-use-consistent-OOM-reporting.patch
Patch127: libvirt-build-Relax-libcurl-version-requirements.patch
Patch128: libvirt-esx-Support-vSphere-4.1.patch
Patch129: libvirt-esx-Improve-blocked-task-detection-and-fix-race-condition.patch

Patch130: libvirt-Fix-patch-to-disable-libvirt-guests-on-xen.patch
Patch131: libvirt-cpuBaseline-Don-t-mess-with-the-CPU-returned-by-arch-driver.patch
Patch132: libvirt-cpuCompare-Fix-comparison-of-two-host-CPUs.patch
Patch133: libvirt-cpu-Fail-when-CPU-type-cannot-be-detected-from-XML.patch
Patch134: libvirt-cpuCompare-Fix-crash-on-unexpected-CPU-XML.patch
Patch135: libvirt-Fix-a-deadlock-in-bi-directional-p2p-concurrent-migration.patch
Patch136: libvirt-pciSharesBusWithActive-fails-to-find-multiple-devices-on-bus.patch
Patch137: libvirt-qemuGetPciHostDeviceList-take-hostdev-list-directly.patch
Patch138: libvirt-Add-helpers-qemuPrepareHostdevPCIDevice-and-qemuDomainReAttachHostdevDevices.patch
Patch139: libvirt-qemudDomainAttachHostPciDevice-refactor-to-use-new-helpers.patch
Patch140: libvirt-pciResetDevice-use-inactive-devices-to-determine-safe-reset.patch
Patch141: libvirt-Force-FLR-on-for-buggy-SR-IOV-devices.patch
Patch142: libvirt-Fix-up-confusing-indentation-in-qemudDomainAttachHostPciDevice.patch
Patch143: libvirt-Fix-a-potential-race-in-pciInitDevice.patch
Patch144: libvirt-libvirt-guests-Don-t-throw-errors-if-libvirtd-is-not-installed.patch
Patch145: libvirt-libvirt-guests-detect-invalid-arguments.patch
Patch146: libvirt-libvirt-guests-enhance-status.patch
Patch147: libvirt-libvirt-guests-add-reload-condrestart.patch
Patch148: libvirt-Do-not-activate-boot-on-on-devices-when-not-using-KVM.patch
Patch149: libvirt-Fix-the-ACS-checking-in-the-PCI-code.patch
Patch150: libvirt-nodeinfo-skip-offline-CPUs.patch
Patch151: libvirt-bridge-Fix-potential-segfault-when-preparing-dnsmasq-arguments.patch
Patch152: libvirt-bridge-Add-dhcp-no-override-option-to-dnsmasq.patch
Patch153: libvirt-Fix-tunnelled-migration-with-qemu-running-as-qemu-qemu.patch
Patch154: libvirt-Move-the-tunnelled-migration-unix-socket-to-var-lib-libvirt-qemu.patch
Patch155: libvirt-Add-explicit-warning-messages-when-failing-to-serialize-to-XDR.patch
Patch156: libvirt-Try-harder-to-send-RPC-error-message-back-to-client.patch
Patch157: libvirt-Log-return-value-for-virConnectGetCapabilities.patch
Patch158: libvirt-Fix-handling-of-sparse-NUMA-topologies.patch
Patch159: libvirt-bridge-Fix-static-only-DHCP-configuration.patch
Patch160: libvirt-virsh-remove-driver-check-from-attach-disk-command.patch
Patch161: libvirt-virsh-Option-for-overriding-disk-type-in-attach-disk.patch
Patch162: libvirt-buf-Fix-possible-infinite-loop-in-EscapeString-VSnprintf.patch

Patch163: libvirt-build-fix-compiler-warning.patch
Patch164: libvirt-libvirtd-improve-the-error-message-displayed-on-tls-client-auth-failure.patch

Patch165: libvirt-qemu-Turn-dynamic-ownership-off-by-default.patch
Patch166: libvirt-libvirt-guests-start-late-and-stop-early.patch
Patch167: libvirt-nodeinfo-work-when-hot-plugging-is-disabled.patch

Patch168: libvirt-xen-Fix-bogus-error-when-attaching-a-device.patch
Patch169: libvirt-xen-fix-logic-bug.patch
Patch170: libvirt-xen-Make-xenDaemon-DeviceFlags-errors-less-confusing.patch
Patch171: libvirt-xen-Fix-logic-bug-in-xenDaemon-DeviceFlags.patch
Patch172: libvirt-xen-xenXMDomain-DeviceFlags-should-obey-all-flags.patch
Patch173: libvirt-xen-Fix-virDomain-At-De-tachDevice.patch
Patch174: libvirt-Don-t-fail-on-missing-D-Bus.patch
Patch175: libvirt-qemu-Prohibit-migration-of-guests-with-host-devices.patch

Patch176: libvirt-vcpu-improve-cpuset-attribute.patch
Patch177: libvirt-vcpu-add-current-attribute-to-vcpu-element.patch
Patch178: libvirt-vcpu-support-maxvcpu-in-domain_conf.patch
Patch179: libvirt-vcpu-improve-vcpu-support-in-xen-command-line.patch
Patch180: libvirt-vcpu-fix-make-check.patch
Patch181: libvirt-Basic-framework-for-auditing-integration.patch
# Patch182: libvirt-Audit-VM-start-stop-suspend-resume.patch
# Patch183: libvirt-Audit-SELinux-label-assignment.patch
Patch184: libvirt-Fix-symbol-exports-remove-duplicated-libvirt_util.la-linkage.patch
# Patch185: libvirt-Fix-compile-errors-in-remote.c-and-newly-added-audit-code.patch
Patch186: libvirt-Add-audit-helper-for-escaping-log-message-strings.patch
Patch187: libvirt-Add-printf-format-attribute-annotation-to-virAuditSend-method.patch
Patch188: libvirt-Add-auditing-of-start-stop-events-to-the-QEMU-driver.patch
Patch189: libvirt-Add-auditing-of-security-label-in-QEMU-driver.patch
Patch190: libvirt-Add-disk-net-resource-auditing-to-QEMU-driver.patch
Patch191: libvirt-Fix-incorrect-use-of-private-data-in-remote-driver.patch
Patch192: libvirt-qemu-Fix-detection-of-drive-readonly-option.patch
Patch193: libvirt-xen-Fix-domain-dump.patch
Patch194: libvirt-schema-Move-timer-element-inside-clock.patch
Patch195: libvirt-qemu-Add-no-kvm-pit-reinject-by-default.patch
Patch196: libvirt-qemu-Wire-up-text-monitor-events.patch
Patch197: libvirt-qemu-Fix-warnings-in-text-monitor-events.patch
Patch198: libvirt-Fix-host-CPU-counting-on-unusual-NUMA-topologies.patch
Patch199: libvirt-xen-Properly-escape-character.patch
Patch200: libvirt-qemu-Use-vga-none-only-if-it-is-supported.patch

Patch201: libvirt-virExec-avoid-undefined-behavior.patch
Patch202: libvirt-virExec-fix-logic-bug.patch
Patch203: libvirt-Add-missing-checks-for-read-only-connections.patch

Patch204: libvirt-Make-error-reporting-in-libvirtd-thread-safe.patch
Patch205: libvirt-daemon-Avoid-resetting-errors-before-they-are-reported.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
URL: http://libvirt.org/
BuildRequires: python-devel

# Used by many of the drivers, so turn it on whenever the
# daemon is present
%if %{with_libvirtd}
Requires: bridge-utils
%endif
%if %{with_network}
Requires: dnsmasq
Requires: iptables
%endif
%if %{with_nwfilter}
Requires: ebtables
Requires: iptables
Requires: iptables-ipv6
%endif
# needed for device enumeration
%if %{with_hal}
Requires: hal
%endif
%if %{with_udev}
Requires: udev >= 145
%endif
%if %{with_polkit}
%if 0%{?fedora} >= 12 || 0%{?rhel} >=6
Requires: polkit >= 0.93
%else
Requires: PolicyKit >= 0.6
%endif
%endif
%if %{with_storage_fs}
# For mount/umount in FS driver
BuildRequires: util-linux
# For showmount in FS driver (netfs discovery)
BuildRequires: nfs-utils
Requires: nfs-utils
# For glusterfs
%if 0%{?fedora} >= 11
Requires: glusterfs-client >= 2.0.1
%endif
%endif
%if %{with_qemu}
# For image compression
Requires: gzip
Requires: bzip2
%if 0%{?rhel} != 5
Requires: lzop
%endif
Requires: xz
%endif
%if %{with_storage_lvm}
# For LVM drivers
Requires: lvm2
%endif
%if %{with_storage_iscsi}
# For ISCSI driver
Requires: iscsi-initiator-utils
%endif
%if %{with_storage_disk}
# For disk driver
Requires: parted
%endif
%if %{with_storage_mpath}
# For multipath support
Requires: device-mapper
%endif
Requires: readline
Requires: ncurses
# So remote clients can access libvirt over SSH tunnel
# (client invokes 'nc' against the UNIX socket on the server)
Requires: nc
%if %{with_sasl}
Requires: cyrus-sasl
# Not technically required, but makes 'out-of-box' config
# work correctly & doesn't have onerous dependencies
Requires: cyrus-sasl-md5
%endif
%if %{with_audit}
BuildRequires: audit-libs-devel
%endif

%if %{with_xen}
BuildRequires: xen-devel
%endif
%if %{with_one}
BuildRequires: xmlrpc-c-devel >= 1.14.0
%endif
BuildRequires: libxml2-devel
BuildRequires: xhtml1-dtds
BuildRequires: readline-devel
BuildRequires: ncurses-devel
BuildRequires: gettext
BuildRequires: gnutls-devel
%if %{with_hal}
BuildRequires: hal-devel
%endif
%if %{with_udev}
BuildRequires: libudev-devel >= 145
BuildRequires: libpciaccess-devel >= 0.10.9
%endif
%if %{with_yajl}
BuildRequires: yajl-devel
%endif
%if %{with_libpcap}
BuildRequires: libpcap-devel
%endif
%if %{with_libnl}
BuildRequires: libnl-devel
%endif
%if %{with_avahi}
BuildRequires: avahi-devel
%endif
%if %{with_selinux}
BuildRequires: libselinux-devel >= 1.33.4-5.6
Requires: libselinux >= 1.33.4-5.6
%endif
%if %{with_network}
BuildRequires: dnsmasq
%endif
BuildRequires: bridge-utils
%if %{with_sasl}
BuildRequires: cyrus-sasl-devel
%endif
%if %{with_polkit}
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
# Only need the binary, not -devel
BuildRequires: polkit >= 0.93
%else
BuildRequires: PolicyKit-devel >= 0.6
%endif
%endif
%if %{with_storage_fs}
# For mount/umount in FS driver
BuildRequires: util-linux
%endif
%if %{with_qemu}
# From QEMU RPMs
BuildRequires: /usr/bin/qemu-img
%else
%if %{with_xen}
# From Xen RPMs
BuildRequires: /usr/sbin/qcow-create
%endif
%endif
%if %{with_storage_lvm}
# For LVM drivers
BuildRequires: lvm2
%endif
%if %{with_storage_iscsi}
# For ISCSI driver
BuildRequires: iscsi-initiator-utils
%endif
%if %{with_storage_disk}
# For disk driver
BuildRequires: parted-devel
%if 0%{?rhel} == 5
# Broken RHEL-5 parted RPM is missing a dep
BuildRequires: e2fsprogs-devel
%endif
%endif
%if %{with_storage_mpath}
# For Multipath support
%if 0%{?rhel} == 5
# Broken RHEL-5 packaging has header files in main RPM :-(
BuildRequires: device-mapper
%else
BuildRequires: device-mapper-devel
%endif
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires: numactl-devel
%endif
%if %{with_capng}
BuildRequires: libcap-ng-devel >= 0.5.0
%endif
%if %{with_phyp}
BuildRequires: libssh2-devel
%endif
%if %{with_netcf}
BuildRequires: netcf-devel >= 0.1.4
%endif
%if %{with_esx}
BuildRequires: curl-devel
%endif

# Fedora build root suckage
BuildRequires: gawk

# for rebuilding makefiles
BuildRequires: autoconf
BuildRequires: automake

# for documentation
BuildRequires: libxslt

%description
Libvirt is a C toolkit to interact with the virtualization capabilities
of recent versions of Linux (and other OSes).

%package devel
Summary: Libraries, includes, etc. to compile with the libvirt library
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig
%if %{with_xen}
Requires: xen-devel
%endif

%description devel
Includes and documentations for the C library providing an API to use
the virtualization capabilities of recent versions of Linux (and other OSes).

%if %{with_python}
%package python
Summary: Python bindings for the libvirt library
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description python
The libvirt-python package contains a module that permits applications
written in the Python programming language to use the interface
supplied by the libvirt library to use the virtualization capabilities
of recent versions of Linux (and other OSes).
%endif

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1
%patch108 -p1
%patch109 -p1
%patch110 -p1
%patch111 -p1
%patch112 -p1
%patch113 -p1
%patch114 -p1
%patch115 -p1
%patch116 -p1
%patch117 -p1
%patch118 -p1
%patch119 -p1
%patch120 -p1
%patch121 -p1
%patch122 -p1
%patch123 -p1
%patch124 -p1
%patch125 -p1
%patch126 -p1
%patch127 -p1
%patch128 -p1
%patch129 -p1
%patch130 -p1
%patch131 -p1
%patch132 -p1
%patch133 -p1
%patch134 -p1
%patch135 -p1
%patch136 -p1
%patch137 -p1
%patch138 -p1
%patch139 -p1
%patch140 -p1
%patch141 -p1
%patch142 -p1
%patch143 -p1
%patch144 -p1
%patch145 -p1
%patch146 -p1
%patch147 -p1
%patch148 -p1
%patch149 -p1
%patch150 -p1
%patch151 -p1
%patch152 -p1
%patch153 -p1
%patch154 -p1
%patch155 -p1
%patch156 -p1
%patch157 -p1
%patch158 -p1
%patch159 -p1
%patch160 -p1
%patch161 -p1
%patch162 -p1
%patch163 -p1
%patch164 -p1
%patch165 -p1
%patch166 -p1
%patch167 -p1
%patch168 -p1
%patch169 -p1
%patch170 -p1
%patch171 -p1
%patch172 -p1
%patch173 -p1
%patch174 -p1
%patch175 -p1
%patch176 -p1
%patch177 -p1
%patch178 -p1
%patch179 -p1
%patch180 -p1
%patch181 -p1
%patch184 -p1
%patch186 -p1
%patch187 -p1
%patch188 -p1
%patch189 -p1
%patch190 -p1
%patch191 -p1
%patch192 -p1
%patch193 -p1
%patch194 -p1
%patch195 -p1
%patch196 -p1
%patch197 -p1
%patch198 -p1
%patch199 -p1
%patch200 -p1

%patch201 -p1
%patch202 -p1
%patch203 -p1

%patch204 -p1
%patch205 -p1

%build
%if ! %{with_xen}
%define _without_xen --without-xen
%endif

%if ! %{with_qemu}
%define _without_qemu --without-qemu
%endif

%if ! %{with_openvz}
%define _without_openvz --without-openvz
%endif

%if ! %{with_lxc}
%define _without_lxc --without-lxc
%endif

%if ! %{with_vbox}
%define _without_vbox --without-vbox
%endif

%if ! %{with_xenapi}
%define _without_xenapi --without-xenapi
%endif

%if ! %{with_sasl}
%define _without_sasl --without-sasl
%endif

%if ! %{with_avahi}
%define _without_avahi --without-avahi
%endif

%if ! %{with_phyp}
%define _without_phyp --without-phyp
%endif

%if ! %{with_esx}
%define _without_esx --without-esx
%endif

%if ! %{with_polkit}
%define _without_polkit --without-polkit
%endif

%if ! %{with_python}
%define _without_python --without-python
%endif

%if ! %{with_libvirtd}
%define _without_libvirtd --without-libvirtd
%endif

%if ! %{with_uml}
%define _without_uml --without-uml
%endif

%if ! %{with_one}
%define _without_one --without-one
%endif

%if %{with_rhel5}
%define _with_rhel5_api --with-rhel5-api
%endif

%if ! %{with_network}
%define _without_network --without-network
%endif

%if ! %{with_storage_fs}
%define _without_storage_fs --without-storage-fs
%endif

%if ! %{with_storage_lvm}
%define _without_storage_lvm --without-storage-lvm
%endif

%if ! %{with_storage_iscsi}
%define _without_storage_iscsi --without-storage-iscsi
%endif

%if ! %{with_storage_disk}
%define _without_storage_disk --without-storage-disk
%endif

%if ! %{with_storage_mpath}
%define _without_storage_mpath --without-storage-mpath
%endif

%if ! %{with_numactl}
%define _without_numactl --without-numactl
%endif

%if ! %{with_capng}
%define _without_capng --without-capng
%endif

%if ! %{with_netcf}
%define _without_netcf --without-netcf
%endif

%if ! %{with_selinux}
%define _without_selinux --without-selinux
%endif

%if ! %{with_hal}
%define _without_hal --without-hal
%endif

%if ! %{with_udev}
%define _without_udev --without-udev
%endif

%if ! %{with_yajl}
%define _without_yajl --without-yajl
%endif

%if ! %{with_libpcap}
%define _without_libpcap --without-libpcap
%endif

%if ! %{with_macvtap}
%define _without_macvtap --without-macvtap
%endif

autoreconf -f

%if ! %{with_audit}
%define _without_audit --without-audit
%endif

%configure %{?_without_xen} \
           %{?_without_qemu} \
           %{?_without_openvz} \
           %{?_without_lxc} \
           %{?_without_vbox} \
           %{?_without_xenapi} \
           %{?_without_sasl} \
           %{?_without_avahi} \
           %{?_without_polkit} \
           %{?_without_python} \
           %{?_without_libvirtd} \
           %{?_without_uml} \
           %{?_without_one} \
           %{?_without_phyp} \
           %{?_without_esx} \
           %{?_without_network} \
           %{?_with_rhel5_api} \
           %{?_without_storage_fs} \
           %{?_without_storage_lvm} \
           %{?_without_storage_iscsi} \
           %{?_without_storage_disk} \
           %{?_without_storage_mpath} \
           %{?_without_numactl} \
           %{?_without_capng} \
           %{?_without_netcf} \
           %{?_without_selinux} \
           %{?_without_hal} \
           %{?_without_udev} \
           %{?_without_yajl} \
           %{?_without_libpcap} \
           %{?_without_macvtap} \
           %{?_without_audit} \
           --with-qemu-user=%{qemu_user} \
           --with-qemu-group=%{qemu_group} \
           --with-init-script=redhat \
           --with-remote-pid-file=%{_localstatedir}/run/libvirtd.pid
make %{?_smp_mflags}
gzip -9 ChangeLog

%install
rm -fr %{buildroot}

%makeinstall
for i in domain-events/events-c dominfo domsuspend hellolibvirt python xml/nwfilter
do
  (cd examples/$i ; make clean ; rm -rf .deps .libs Makefile Makefile.in)
done
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/python*/site-packages/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/python*/site-packages/*.a

%if %{with_network}
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/lib/libvirt/dnsmasq/
# We don't want to install /etc/libvirt/qemu/networks in the main %files list
# because if the admin wants to delete the default network completely, we don't
# want to end up re-incarnating it on every RPM upgrade.
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
# Strip auto-generated UUID - we need it generated per-install
sed -i -e "/<uuid>/d" $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
%else
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
%endif
%if ! %{with_qemu}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%endif
%find_lang %{name}

%if ! %{with_lxc}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%endif

%if ! %{with_python}
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/libvirt-python-%{version}
%endif

%if %{client_only}
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/libvirt-%{version}
%endif

%if ! %{with_libvirtd}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter
%endif

%if ! %{with_qemu}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu
%else
mv -f $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu \
      $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd
%endif

%if ! %{with_lxc}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/lxc.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if ! %{with_uml}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.uml
%endif

%if %{with_libvirtd}
chmod 0644 $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/libvirtd
%endif

%clean
rm -fr %{buildroot}

%check
cd tests
# These 3 tests don't current work in a mock build root
for i in nodeinfotest daemon-conf seclabeltest
do
  rm -f $i
  printf "#!/bin/sh\nexit 0\n" > $i
  chmod +x $i
done
# This currently fails on RHEL-5 due to buggy libxml2
for i in interfaceschematest
do
  rm -f $i
  printf "#!/bin/sh\nexit 0\n" > $i
  chmod +x $i
done
make check

%pre
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
# Normally 'setup' adds this in /etc/passwd, but this is
# here for case of upgrades from earlier Fedora/RHEL. This
# UID/GID pair is reserved for qemu:qemu
getent group kvm >/dev/null || groupadd -g 36 -r kvm
getent group qemu >/dev/null || groupadd -g 107 -r qemu
getent passwd qemu >/dev/null || \
  useradd -r -u 107 -g qemu -G kvm -d / -s /sbin/nologin \
    -c "qemu user" qemu
%endif

%post

%if %{with_libvirtd}
%if %{with_network}
# We want to install the default network for initial RPM installs
# or on the first upgrade from a non-network aware libvirt only.
# We check this by looking to see if the daemon is already installed
/sbin/chkconfig --list libvirtd 1>/dev/null 2>&1
if test $? != 0 && test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml
then
    UUID=`/usr/bin/uuidgen`
    sed -e "s,</name>,</name>\n  <uuid>$UUID</uuid>," \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
    ln -s ../default.xml %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
fi
%endif

/sbin/chkconfig --add libvirtd
if [ "$1" -ge "1" ]; then
	/sbin/service libvirtd condrestart > /dev/null 2>&1
fi
%endif

/sbin/ldconfig
/sbin/chkconfig --add libvirt-guests
if [ $1 -ge 1 ]; then
    # this doesn't do anything but allowing for libvirt-guests to be
    # stopped on the first shutdown
    /sbin/service libvirt-guests start > /dev/null 2>&1 || true
fi

%preun
%if %{with_libvirtd}
if [ $1 = 0 ]; then
    /sbin/service libvirtd stop 1>/dev/null 2>&1
    /sbin/chkconfig --del libvirtd
fi
%endif

if [ $1 = 0 ]; then
    /sbin/chkconfig --del libvirt-guests
    rm -f /var/lib/libvirt/libvirt-guests
fi

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%if %{with_libvirtd}
%defattr(-, root, root)

%doc AUTHORS ChangeLog.gz NEWS README COPYING.LIB TODO
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/

%if %{with_network}
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%endif

%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%{_sysconfdir}/libvirt/nwfilter/*.xml

%{_sysconfdir}/rc.d/init.d/libvirtd
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/uml/

%if %{with_qemu}
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%endif
%if %{with_lxc}
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if %{with_uml}
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.uml
%endif

%dir %{_datadir}/libvirt/

%if %{with_network}
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml
%endif

%dir %{_localstatedir}/run/libvirt/

%dir %{_localstatedir}/lib/libvirt/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0700, root, root) %{_localstatedir}/cache/libvirt/

%if %{with_qemu}
%dir %attr(0700, root, root) %{_localstatedir}/run/libvirt/qemu/
%dir %attr(0700, %{qemu_user}, %{qemu_group}) %{_localstatedir}/lib/libvirt/qemu/
%dir %attr(0700, %{qemu_user}, %{qemu_group}) %{_localstatedir}/cache/libvirt/qemu/
%endif
%if %{with_lxc}
%dir %{_localstatedir}/run/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%endif
%if %{with_uml}
%dir %{_localstatedir}/run/libvirt/uml/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/uml/
%endif
%if %{with_network}
%dir %{_localstatedir}/run/libvirt/network/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%endif

%if %{with_qemu}
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%endif

%if %{with_lxc}
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%endif

%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug

%if %{with_polkit}
%if 0%{?fedora} >= 12 || 0%{?rhel} >= 6
%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%else
%{_datadir}/PolicyKit/policy/org.libvirt.unix.policy
%endif
%endif

%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/

%if %{with_xen_proxy}
%attr(4755, root, root) %{_libexecdir}/libvirt_proxy
%endif

%if %{with_lxc}
%attr(0755, root, root) %{_libexecdir}/libvirt_lxc
%endif

%attr(0755, root, root) %{_libexecdir}/libvirt_parthelper
%attr(0755, root, root) %{_sbindir}/libvirtd

%{_mandir}/man8/libvirtd.8*

%doc docs/*.xml
%endif

%{_mandir}/man1/virsh.1*
%{_mandir}/man1/virt-xml-validate.1*
%{_mandir}/man1/virt-pki-validate.1*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate
%{_libdir}/lib*.so.*

%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/

%{_datadir}/libvirt/schemas/domain.rng
%{_datadir}/libvirt/schemas/domainsnapshot.rng
%{_datadir}/libvirt/schemas/network.rng
%{_datadir}/libvirt/schemas/storagepool.rng
%{_datadir}/libvirt/schemas/storagevol.rng
%{_datadir}/libvirt/schemas/nodedev.rng
%{_datadir}/libvirt/schemas/capability.rng
%{_datadir}/libvirt/schemas/interface.rng
%{_datadir}/libvirt/schemas/secret.rng
%{_datadir}/libvirt/schemas/storageencryption.rng
%{_datadir}/libvirt/schemas/nwfilter.rng

%{_datadir}/libvirt/cpu_map.xml

%{_sysconfdir}/rc.d/init.d/libvirt-guests
%config(noreplace) %attr(0644, root, root) %{_sysconfdir}/sysconfig/libvirt-guests

%if %{with_sasl}
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%endif

%files devel
%defattr(-, root, root)

%{_libdir}/lib*.so
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/*.h
%{_libdir}/pkgconfig/libvirt.pc
%dir %{_datadir}/gtk-doc/html/libvirt/
%doc %{_datadir}/gtk-doc/html/libvirt/*.devhelp
%doc %{_datadir}/gtk-doc/html/libvirt/*.html
%doc %{_datadir}/gtk-doc/html/libvirt/*.png
%doc %{_datadir}/gtk-doc/html/libvirt/*.css

%doc docs/*.html docs/html docs/*.gif
%doc docs/libvirt-api.xml
%doc examples/hellolibvirt
%doc examples/domain-events/events-c
%doc examples/dominfo
%doc examples/domsuspend
%doc examples/xml

%if %{with_python}
%files python
%defattr(-, root, root)

%doc AUTHORS NEWS README COPYING.LIB
%{_libdir}/python*/site-packages/libvirt.py*
%{_libdir}/python*/site-packages/libvirtmod*
%doc python/tests/*.py
%doc python/TODO
%doc examples/python
%doc examples/domain-events/events-python
%endif

%changelog
* Tue Apr 19 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-15.el5_6.4
- Make error reporting in libvirtd thread safe (CVE-2011-1486)

* Thu Mar 17 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-15.el5_6.3
- Properly report error in virConnectDomainXMLToNative (CVE-2011-1146)
- Guess rhel macro based on dist macro (rhbz#688728)

* Mon Mar 14 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-15.el5_6.2
- Add missing checks for read-only connections (CVE-2011-1146)

* Tue Jan 04 2011 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-15.el5_6.1
- Fix possible crash in virExec (rhbz#667142)

* Wed Dec 08 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-15.el5
- Use '-vga none' only if it is supported by qemu (rhbz#661152)

* Wed Nov 24 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-14.el5
- Really apply the "Properly escape & character in xen driver" patch

* Wed Nov 24 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-13.el5
- Fix warnings in text monitor events (rhbz #574017)
- Fix host CPU counting on unusual NUMA topologies (rhbz #654540)
- Properly escape & character in xen driver (rhbz #472437)

* Tue Nov 16 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-12.el5
- Add support for async events in qemu text monitor (rhbz #574017)

* Wed Nov 10 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-11.el5
- Add -no-kvm-pit-reinject by default to qemu guests (rhbz #649214)

* Fri Oct 29 2010 Daniel P. Berrange <berrange@redhat.com> - 0.8.2-10.el5
- Add missing BuildRequires on audit-libs-devel  (rhbz #587280)

* Wed Oct 27 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-9.el5
- Reworked audit support (rhbz #587280)
- Fix incorrect use of private data in remote driver (rhbz #646717)
- Fix detection of qemu's drive readonly option (rhbz #510612)
- Fix Xen domain dump (rhbz #646755)

* Wed Oct 20 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-8.el5
- Add 'current' attribute to <vcpu> element (rhbz #545118)
- Don't build xenapi driver even if libxenserver is found (rhbz #643118)
- Audit support (rhbz #587280)

* Thu Oct 14 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-7.el5
- Fix bogus error when attaching a device to xen guest (rhbz #638472)
- Fix device hotplug on xen (rhbz #638520)
- Don't fail on missing D-Bus (rhbz #642650)
- Prohibit migration of qemu guests with host devices (rhbz #573940)
- Remove explicit dependency on qcow-create and qemu-img tools (rhbz #642026)

* Thu Sep 23 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-6.el5
- Turn dynamic ownership off by default (rhbz #636477)
- Rename libvirtd.qemu in /etc/logrotate.d back to libvirtd (rhbz #636460)
- Start libvirt-guests late and stop it early to solve dependency on xend (rhbz #636447)
- Fix failure when host kernel doesn't support CPU hot-plugging (rhbz #636347)

* Tue Sep 21 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-5.el5
- Fix possible compiler warning in libvirt-nodedev-Fix-sysfs-paths-for-vport-operations.patch
- Improve the error message displayed on TLS client auth failure (rhbz #556599)
- Explicitly require new enough libselinux in runtime (rhbz #635028)

* Mon Sep 13 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-4.el5
- Fix patch to disable libvirt-guests on xen
- Fix virConnectBaselineCPU (rhbz #630616)
- Fix comparison of two host CPUs (rhbz #630615)
- Fail when CPU type cannot be detected from XML (rhbz #630617)
- Fix crash on unexpected CPU XML (rhbz #630618)
- Fix a deadlock in bi-directional p2p concurrent migration (rhbz #630614)
- Fix multiple PCI device assignment bugs (rhbz #630620)
- Fix confusing error in libvirt-guests (rhbz #630622)
- Update libvirt-guests to Fedora init script standards (rhbz #630621)
- Do not activate boot=on on devices when not using KVM (rhbz #630613)
- Fix the ACS checking in the PCI code (rhbz #630619)
- Skip offline CPUs in nodeinfo (rhbz #630624)
- Fix PXE boot on virtual network (rhbz #630627)
- Fix tunnelled migration with qemu running as qemu:qemu (rhbz #630625)
- Fix problem with capabilities XML generation (rhbz #630626)
- Fix static-only DHCP configuration (rhbz #597363)
- Fix virsh attach-disk command (rhbz #609422)
- Fix virsh create hang (rhbz #602772) 

* Wed Sep  8 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-3.el5
- Fix bogus free of static strings introduced by a patch for CVE-2010-2239
- Enable nwfilter driver (rhbz #630574)
- Enable ESX driver (rhbz #629005)

* Fri Sep  3 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-2.el5
- Fix permissions of /var/lib/libvirt directory
- Require new libselinux for SELinux security driver
- Add man page for libvirtd (rhbz #618750)

* Thu Sep  2 2010 Jiri Denemark <jdenemar@redhat.com> - 0.8.2-1.el5
- Rebased to upstream 0.8.2 release (rhbz #544303)
- Also fixes 28 other bugs

* Thu Jul 29 2010 Jiri Denemark <jdenemar@redhat.com> - 0.6.3-37.el5
- Explicitly set qcow2 backing store format (CVE-2010-2239)
- Remap privileged source ports from guests behind NAT (CVE-2010-2242)
- Eliminate memory leak in xenUnifiedDomainInfoListFree (rhbz 590073)

* Mon Jul 26 2010 Jiri Denemark <jdenemar@redhat.com> - 0.6.3-36.el5
- Fix discrepancy between xm list and virsh list (rhbz 593120)

* Fri Jul 23 2010 Jiri Denemark <jdenemar@redhat.com> - 0.6.3-35.el5
- Set a stable & high MAC addr for guest TAP devices on host (rhbz 571991)

* Sun Jun  6 2010 Jiri Denemark <jdenemar@redhat.com> - 0.6.3-34.el5
- Set CPU affinity across whole QEMU process (rhbz 576920)
- Show more helpful migration errors (rhbz 568476)
- Report NUMA and CPU info correctly with nodeinfo (rhbz 570527)
- Allow hostname only with migrateuri (rhbz 595992)

* Wed Mar  3 2010 Jiri Denemark <jdenemar@redhat.com> - 0.6.3-33.el5
- Conflict with kvm release older than kvm-83-142.el5 (rhbz 569372)
- Call fsync() at the end instead of opening raw files with O_DSYNC (rhbz 563151)

* Wed Feb 10 2010 Jiri Denemark <jdenemar@redhat.com> - 0.6.3-32.el5
- Make numa errors non-fatal (rhbz 559755)
- Create raw storage files with O_DSYNC (rhbz 563151)
- Increase qemu guest startup timeout to 30 seconds (rhbz 563151)

* Thu Jan 28 2010 Jiri Denemark <jdenemar@redhat.com> - 0.6.3-31.el5
- Fix ACS with root devices (rhbz 526713)
- Fix PCI device re-assignment (rhbz 500217)
- Fix a race between KVM and libvirt (rhbz 500217)
- Fix state bug in libvirtd (rhbz 500217)
- Set machine type to "rhel5.4.0" by default (rhbz 542665)
- Correct erroneous expression in pciDeviceDownstreamLacksACS (rhbz 526713)

* Thu Jan 14 2010 Daniel Veillard <veillard@redhat.com> - 0.6.3-30.el5
- fix crash in xenUnifiedNodeDeviceReset
- Resolves: rhbz#555309
- avoid spurious errors on npiv device creation
- Resolves: rhbz#514324

* Wed Jan  6 2010 Daniel Veillard <veillard@redhat.com> - 0.6.3-29.el5
- fix a problem with memory allocation when using huge pages
- Resolves: rhbz#518099

* Wed Dec 23 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-28.el5
- volume create failure can lead to daemon crash
- Resolves: rhbz#510450

* Tue Dec 22 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-27.el5
- block assignment of devices below non-ACS switch
- Resolves: rhbz#526713

* Tue Dec 22 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-26.el5
- avoid some unknown failure error reports
- Resolves: rhbz#531729
- avoid "error: unknown procedure" when querying older libvirt
- Resolves: rhbz#531735
- remove limit on number of tap devices and guest
- Resolves: rhbz#519729
- avoid crashes when having concurrent TLS connections
- Resolves: rhbz#512367

* Tue Dec 15 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-25.el5
- fix python binding generator to avoid clashes in method names
- Resolves: rhbz#510427
- nodedev-destroy can hang libvirtd
- Resolves: rhbz#510430
- avoid spurious errors on npiv device creation
- Resolves: rhbz#514324
- node device APIs should expose the relationship between SR-IOV VFs and PFs
- Resolves: rhbz#481748
- implement --pool option for virsh vol-path
- Resolves: rhbz#509306
- cannot delete storage pool problem
- Resolves: rhbz#496579
- Can not hotplug vtd device to Xen guest
- Resolves: rhbz#546671
- Inactive KVM guest memory reporting via 'info' is strange
- Resolves: rhbz#508266
- command 'virsh nodedev-create' fails with out of memory error
- Resolves: rhbz#510426
- Command 'virsh find-storage-pool-sources' failure unknown error
- Resolves: rhbz#509979

* Thu Dec 10 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-24.el5
- guest host present two NIC with duplicate MAC addresses, only one configured
- Resolves: rhbz#483884
- implement core dump API for QEMU driver
- Resolves: rhbz#507551
- reset a PCI function even if other unused devices/functions are reset
- Resolves: rhbz#500213
- avoid a crash with virsh vol-key volname
- Resolves: rhbz#509293

* Fri Dec  4 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-23.el5
- enable bridges even without IP assigend yet
- Resolves: rhbz#532834
- PCI device assigned need to be reattached to host on guest shutdown
- Resolves: rhbz#500217
- allow PCI PM reset on multi-function devices
- Resolves: rhbz#517460
- support for KVM PCI device assignment hotplug
- Resolves: rhbz#517465

* Wed Nov 25 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-22.el5
- xen driver need check for duplicate uuid
- Resolves: rhbz#504262
- xen credit scheduler doesn't handle cap value 65535
- Resolves: rhbz#504914
- domain XML dump broke with virt-xml-validate
- Resolves: rhbz#512069
- libvirt did not report vCPU usage properly
- Resolves: rhbz#514082
- virsh man page sugegsted operation were asynchronous
- Resolves: rhbz#514532
- add support for qemu hugepages control
- Resolves: rhbz#518099
- libvirt was reordering drives based on their type
- Resolves: rhbz#521053
- a typo in domain interface definitions could generate a segfault
- Resolves: rhbz#523418
- dnsmasq used to limit the number of DHCP leases to only 150
- Resolves: rhbz#524280

* Mon Aug 17 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-21.el5
- Add -no-kvm-pit-reinjection to kvm command line to keep guest time
- resolves: rhbz#517278

* Tue Aug  4 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-20.el5
- redefining a Xen domain could reset the domain id
- fix Xen inotify checking of /etc/xen and avoid vanishing domains
- resolves: rhbz#508278

* Tue Aug  4 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-18.el5
- fix FLR flag detection
- resolves: rhbz#514921

* Tue Jul 28 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-17.el5
- an error in pci definition could lead to a daemon crash
- resolves: rhbz#513317

* Wed Jul 22 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-16.el5
- fix for 502095 the qemu driver was using the old pci_add/del syntax
- resolves: rhbz#502095

* Wed Jul 15 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-15.el5
- fix for 506688 wasn't complete as remote access was still failing
- resolves: rhbz#506688

* Thu Jul  2 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-14.el5
- fix broken behavior on wrong pool creation
- Resolves: rhbz#496616
- fix hang of libvirt daemon on node device XML dump
- Resolves: rhbz#509261

* Wed Jul  1 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-13.el5
- fix a crash when getting wwns failed
- Resolves: rhbz#504285

* Fri Jun 26 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-12.el5
- fix bogus WWNs when HBA kernel modules are (re)loaded
- remove a small leak with SCSI node device conf
- Resolves: rhbz#496925

* Fri Jun 19 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-11.el5
- NPIV didn't work due to different paths in /sys for older kernels
- Resolves: rhbz#496925
- the domain info API would fail due to the absence of a security model
- Resolves: rhbz#506688

* Mon Jun 15 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-10.el5
- detaching Xen devices led to segfaults, another problem
- Resolves: rhbz#497051

* Fri Jun 12 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-9.el5
- fix segfaults on devices operations on Xen
- Resolves: rhbz#504285

* Wed Jun 10 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-8.el5
- the libexec patch wasn't working due to a remaining check in /usr/bin
- Resolves: rhbz#504046

* Wed Jun 10 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-7.el5
- remote driver using tls by default didn't work
- Resolves: rhbz#504775

* Fri Jun  5 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-6.el5
- look for kvm binary in libexec
- Resolves: rhbz#504046
- Fix build support for qcow2 on x86_64 due to missing binary at build time
- Resolves: rhbz#504119
- Take ownership of the %{_datadir}/augeas subtree
- Resolves: rhbz#481809

* Thu Jun  4 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-5.el5
- error in handling hostdev managed informations
- Resolves: rhbz#499577
- detaching Xen devices led to segfaults
- Resolves: rhbz#497051

* Wed Jun  3 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-4.el5
- implement NPIV node device create and destroy
- Resolves: rhbz#496925
- avoid daemon crash on TLS auth errors
- Resolves: rhbz#503178
- forbid to set autostart on transcient networks
- Resolves: rhbz#503481

* Thu May 14 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-3.el5
- Fix serious event handling bug possibly killing random domains
- Resolves: rhbz#500158
- XML attribute escaping fix
- Handle recent QEmu help output
- Hash destructors should use unref not free
- Fix some name and uuid uniqueness checks
- Fix save/restore/migrate for qemu >= 0.10.0
- Fix QEmu capabilities refresh
- Extra check in pid file access routines
- Related: rhbz#475821

* Tue Apr 28 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-2.el5
- Fix missing ownership of /usr/share/gtk-doc/html/libvirt from spec file
- Resolves: rhbz#481809
- Related: rhbz#475821

* Fri Apr 24 2009 Daniel Veillard <veillard@redhat.com> - 0.6.3-1.el5
- Upstream release 0.6.3
- various bug fixes
- a couple of packaging fixes including #496867
- Related: rhbz#475821

* Mon Apr  6 2009 Daniel Veillard <veillard@redhat.com> - 0.6.2-1.el5
- Upstream release 0.6.2
- numerous bug fixes
- SCSI storage pool support
- Related: rhbz#475821

* Mon Mar 16 2009 Daniel Veillard <veillard@redhat.com> - 0.6.1-4.el5
- another serious fd leak fix for 0.6.1
- Related: rhbz#475821

* Mon Mar 16 2009 Daniel Veillard <veillard@redhat.com> - 0.6.1-3.el5
- 8 more bug fixes against 0.6.1
- Related: rhbz#475821

* Wed Mar 11 2009 Daniel Veillard <veillard@redhat.com> - 0.6.1-2.el5
- fixes a couple of Xen bugs in 0.6.1
- Related: rhbz#475821

* Thu Mar  5 2009 Daniel Veillard <veillard@redhat.com> - 0.6.1-1.el5
- Rebase to upstream release 0.6.1
- Resolves: rhbz#475821

* Wed Feb 18 2009 Daniel P. Berrange <berrange@redhat.com> - 0.3.3-15.el5
- Add missing readonly checks for APIs (CVE-2008-5086)
- Add missing buf check in proxy daemon (CVE-2009-0036)

* Fri Sep 19 2008 Richard W.M. Jones <rjones@redhat.com> - 0.3.3-14.el5
- add patch to keep VNC port number same as defined at installation
- Resolves: rhbz#442140

* Tue Sep 16 2008 Chris Lalancette <clalance@redhat.com> - 0.3.3-13.el5
- add patch to allow block statistics to see expanded Xen PV devices
- Resolves: rhbz#458968

* Tue Aug 26 2008 Daniel Veillard <veillard@redhat.com> - 0.3.3-12.el5
- add requires to xen-devel for the -devel package
- Resolves: rhbz#460138

* Wed Jul  9 2008 Daniel Veillard <veillard@redhat.com> - 0.3.3-11.el5
- add a Requires to nc
- Resolves: rhbz#450556

* Fri Jul  4 2008 Daniel Veillard <veillard@redhat.com> - 0.3.3-10.el5
- order of interface bug fix
- Resolves: rhbz#442730

* Thu Jun 19 2008 Daniel Veillard <veillard@redhat.com> - 0.3.3-9.el5
- man page fix
- Resolves: rhbz#442429
- allow to change a Disk/Nic of inactive domain
- Resolves: rhbz#251640
- XML string escaping in xm driver
- Resolves: rhbz#428879

* Wed Jun 18 2008 Daniel Veillard <veillard@redhat.com> - 0.3.3-8.el5
- man page fix
- Resolves: rhbz#442429
- removal of extra_release macro
- Resolves: rhbz#436803
- allow to change a Disk/Nic of inactive domain
- Resolves: rhbz#251640
- fix a hash table bug
- Resolves: rhbz#448533

* Tue Apr  1 2008 Daniel P. Berrange <berrange@redhat.com> - 0.3.3-7.el5
- Fix USB input device XML handling (rhbz #225391)

* Wed Mar 19 2008 Daniel P. Berrange <berrange@redhat.com> - 0.3.3-6.el5
- Fix off-by-on in SSH tunnel args checking (rhbz #431723)

* Wed Jan 23 2008 Daniel Veillard <veillard@redhat.com> - 0.3.3-5.el5
- fix network Paravirt drivers on HVM
- clarify documentation for virsh setcpus and setmem commands
- Resolves: rhbz#429301
- Resolves: rhbz#429186

* Thu Jan 10 2008 Daniel Veillard <veillard@redhat.com> - 0.3.3-4.el5
- one more patch to fix VCPU pinning
- Resolves: rhbz#223833

* Wed Jan  9 2008 Daniel Veillard <veillard@redhat.com> - 0.3.3-3.el5
- add patch to fix NUMA compatibility problem with backport to xen-3.0.3
- re-add a RHEL specific patch for PVFB on 3.0.3
- renamed the second disk ID patch
- Resolves: rhbz#426324

* Tue Dec 18 2007 Daniel Veillard <veillard@redhat.com> - 0.3.3-2.el5
- add 3 patches fixing NUMA disk detach for tap devices, setting cpu
  parameter on inactive domains and an escaping bug
- Resolves: rhbz#251641
- Resolves: rhbz#346281

* Sun Sep 30 2007 Daniel Veillard <veillard@redhat.com> - 0.3.3-1.el5
- Update to 0.3.3
- Avahi support
- NUMA support
- APIs for collecting statistics on disks and interfaces
- API for domains migration
- localtime clock support
- PS/2 and USB input devices
- Secure remote access support
- unification of daemons
- lots of assorted improvements, bugfixes and cleanups
- documentation and localization improvements
- Resolves: rhbz#223833
- Resolves: rhbz#235851
- Resolves: rhbz#251641
- Resolves: rhbz#251706
- Resolves: rhbz#253494
- Resolves: rhbz#254051
- Resolves: rhbz#273421
- Resolves: rhbz#306931
- Resolves: rhbz#328841
- Resolves: rhbz#346281

* Tue Aug 28 2007 Daniel Veillard <veillard@redhat.com> - 0.2.3-9.el5
- patch to fix the pvfb vncdisplay port in XML dumps
- Resolves: rhbz #254188
- Related: rhbz #250789

* Fri Aug 17 2007 Hugh O. Brock <hbrock@redhat.com> - 0.2.3-8.el5
- Overhaul man page to accurately reflect the available commands
- Resolves: rhbz #253013

* Tue Aug 14 2007 Daniel Veillard <veillard@redhat.com> - 0.2.3-7.el5
- Fix UUID lookup though proxy (i.e. as user)
- Resolves: rhbg#224415

* Mon Aug 13 2007 Daniel Veillard <veillard@redhat.com> - 0.2.3-6.el5
- Fix handling of PVFB configurations
- Resolves: rhbg#250789
- Fix config file when using virtual network
- Resolves: rhbg#251594

* Tue Jul 31 2007 Daniel Veillard <veillard@redhat.com> - 0.2.3-5.el5
- Fix a leak when closing a connection
- Resolves: rhbg#250146

* Wed Jun 27 2007 Daniel Berrange <berrange@redhat.com> - 0.2.3-4.el5
- Re-add multilib fix from 0.1.8-14.el5 accidentally lost in 0.2.3-1.el5
- Related: rhbz#243463

* Tue Jun 19 2007 Daniel Veillard <veillard@redhat.com> 0.2.3-3.el5
- add new, more convenient commands for device attach and detach in virsh
- Resolves: rhbz#234840

* Tue Jun 19 2007 Daniel Veillard <veillard@redhat.com> 0.2.3-2.el5
- add Requires: dnsmasq
- Resolves: rhbz#244247

* Thu Jun 14 2007 Daniel Veillard <veillard@redhat.com> 0.2.3-1.el5
- Upgrade to version 0.2.3 for RHEL-5.1
- Resolves: rhbz#243463
- Resolves: rhbz#222704
- Resolves: rhbz#224415
- Resolves: rhbz#225566
- Resolves: rhbz#225567
- Resolves: rhbz#229176
- Note: 0.2.3 is really supposed to work with dnsmask which is not 
  available at the moment in RHEL-5

* Thu Jan 25 2007 Daniel Berrange <berrange@redhat.com> 0.1.8-15.el5
- re-do the localization patch, so that we don't have to run
  'make update-po', and thus avoid multilib conflicts
- Resolves: rhbz#224446

* Thu Jan 25 2007 Daniel Berrange <berrange@redhat.com> 0.1.8-14.el5
- further fix for parallel installation problem of -devel on i386 and x86_64
- Resolves: rhbz#222730

* Thu Jan 18 2007 Daniel Veillard <veillard@redhat.com> 0.1.8-13.el5
- last update of localization for RHEL languages
- Resolves: rhbz#203726 	

* Thu Dec 21 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-12.el5
- fix a parallel installation problem of -devel on i386 and x86_64
- Resolves: rhbz#222730

* Thu Dec 21 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-11.el5
- updates localization for RHEL languages
- Related: rhbz#203726 	

* Wed Dec 13 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-10.el5
- fix the maxid array overflow when listing domains, rhbz#218789
- Resolves: rhbz#218789

* Wed Dec 13 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-9.el5
- Add the two pvfb patches, rhbz#218486
- Resolves: rhbz#218486

* Thu Dec  7 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-8.el5
- fix a structure error when asking the hypervisor for vcpu info, rhbz#217743
  and rhbz#217370
- Resolves: rhbz#217370 rhbz#217743

* Thu Dec  7 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-7.el5
- release python global interpreter lock when calling libvirt, rhbz#210140
- return correct os type version for HVM guests when running as non-root, 
  rhbz#214264
- Resolves: rhbz#210140 rhbz#214264

* Thu Dec  7 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-6.el5
- save the amount of current memory used when dumping XML if different from
  maximum amount, and use that when restarting the domain from the XML,
  rhbz#214354
- when using a pygrub bootloader, strip the os informations because xend
  assumes they take precedence over bootloader, rhbz#214741
- Resolves: rhbz#214354 rhbz#214741

* Thu Dec  7 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-5.el5
- patch adding a domain core dump entry point to the library, it requires
  xen >= 3_0_3-13_el5 to get the xend server side support
- Resolves: rhbz#214913

* Mon Dec  4 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-4.el5
- add localization updates for RHEL languages
- Resolves: rhbz#203726 	

* Mon Dec  4 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-3.el5
- add support for shareable disks
- Resolves: rhbz#214908

* Tue Oct 31 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-2.el5
- avoid Xend 404 GET error message when listing non-existent domain
- Resolves: rhbz#207166

* Mon Oct 16 2006 Daniel Veillard <veillard@redhat.com> 0.1.8-1.el5
- another ia64 page size fix
- vcpu number initialization
- don't label crashed domains as shut off
- fix virsh man page
- compile fix

* Sat Oct  7 2006 Daniel P. Berrange <berrange@redhat.com> 0.1.7-3.el5
- add new <driver> element to support blktap backed disks

* Mon Oct  2 2006 Daniel Veillard <veillard@redhat.com> 0.1.7-2
- fix missing page size detection code for ia64
- fix mlock size when getting domain info list from hypervisor

* Fri Sep 22 2006 Daniel Veillard <veillard@redhat.com> 0.1.7-1
- Fix bug when running against xen-3.0.3 hypercalls
- Fix memory bug when getting vcpus info from xend

* Fri Sep 22 2006 Daniel Veillard <veillard@redhat.com> 0.1.6-1
- Support for localization
- Support for new Xen-3.0.3 cdrom and disk configuration
- Support for setting VNC port
- Fix bug when running against xen-3.0.2 hypercalls
- Fix reconnection problem when talking directly to http xend

* Tue Sep  5 2006 Jeremy Katz <katzj@redhat.com> - 0.1.5-3
- patch from danpb to support new-format cd devices for HVM guests

* Tue Sep  5 2006 Daniel Veillard <veillard@redhat.com> 0.1.5-2
- reactivating ia64 support

* Tue Sep  5 2006 Daniel Veillard <veillard@redhat.com> 0.1.5-1
- new release
- bug fixes
- support for new hypervisor calls
- early code for config files and defined domains

* Mon Sep  4 2006 Daniel Berrange <berrange@redhat.com> - 0.1.4-5
- add patch to address dom0_ops API breakage in Xen 3.0.3 tree

* Mon Aug 28 2006 Jeremy Katz <katzj@redhat.com> - 0.1.4-4
- add patch to support paravirt framebuffer in Xen 

* Mon Aug 21 2006 Daniel Veillard <veillard@redhat.com> 0.1.4-3
- another patch to fix network handling in non-HVM guests

* Thu Aug 17 2006 Daniel Veillard <veillard@redhat.com> 0.1.4-2
- patch to fix virParseUUID()

* Wed Aug 16 2006 Daniel Veillard <veillard@redhat.com> 0.1.4-1
- vCPUs and affinity support
- more complete XML, console and boot options
- specific features support
- enforced read-only connections
- various improvements, bug fixes

* Wed Aug  2 2006 Jeremy Katz <katzj@redhat.com> - 0.1.3-6
- add patch from pvetere to allow getting uuid from libvirt

* Wed Aug  2 2006 Jeremy Katz <katzj@redhat.com> - 0.1.3-5
- build on ia64 now

* Thu Jul 27 2006 Jeremy Katz <katzj@redhat.com> - 0.1.3-4
- don't BR xen, we just need xen-devel

* Thu Jul 27 2006 Daniel Veillard <veillard@redhat.com> 0.1.3-3
- need rebuild since libxenstore is now versionned

* Mon Jul 24 2006 Mark McLoughlin <markmc@redhat.com> - 0.1.3-2
- Add BuildRequires: xen-devel

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 0.1.3-1.1
- rebuild

* Tue Jul 11 2006 Daniel Veillard <veillard@redhat.com> 0.1.3-1
- support for HVM Xen guests
- various bugfixes

* Mon Jul  3 2006 Daniel Veillard <veillard@redhat.com> 0.1.2-1
- added a proxy mechanism for read only access using httpu
- fixed header includes paths

* Wed Jun 21 2006 Daniel Veillard <veillard@redhat.com> 0.1.1-1
- extend and cleanup the driver infrastructure and code
- python examples
- extend uuid support
- bug fixes, buffer handling cleanups
- support for new Xen hypervisor API
- test driver for unit testing
- virsh --conect argument

* Mon Apr 10 2006 Daniel Veillard <veillard@redhat.com> 0.1.0-1
- various fixes
- new APIs: for Node information and Reboot
- virsh improvements and extensions
- documentation updates and man page
- enhancement and fixes of the XML description format

* Tue Feb 28 2006 Daniel Veillard <veillard@redhat.com> 0.0.6-1
- added error handling APIs
- small bug fixes
- improve python bindings
- augment documentation and regression tests

* Thu Feb 23 2006 Daniel Veillard <veillard@redhat.com> 0.0.5-1
- new domain creation API
- new UUID based APIs
- more tests, documentation, devhelp
- bug fixes

* Fri Feb 10 2006 Daniel Veillard <veillard@redhat.com> 0.0.4-1
- fixes some problems in 0.0.3 due to the change of names

* Wed Feb  8 2006 Daniel Veillard <veillard@redhat.com> 0.0.3-1
- changed library name to libvirt from libvir, complete and test the python 
  bindings

* Sun Jan 29 2006 Daniel Veillard <veillard@redhat.com> 0.0.2-1
- upstream release of 0.0.2, use xend, save and restore added, python bindings
  fixed

* Wed Nov  2 2005 Daniel Veillard <veillard@redhat.com> 0.0.1-1
- created
